@@ -2,11 +2,11 @@
 #######################################################################
 """Adapter article to rss-entry
 
-$Id: article2rssentryadapter.py 51196 2008-06-26 14:16:21Z cray $
+$Id: article2rssentryadapter.py 51921 2008-10-21 19:07:20Z cray $
 """
 __author__  = "Andrey Orlov, 2008"
 __license__ = "GPL"
-__version__ = "$Revision: 51196 $"
+__version__ = "$Revision: 51921 $"
 
 from zope.app.zapi import getUtility
 from zope.component import ComponentLookupError
@@ -16,21 +16,31 @@ from ng.adapter.mtime.interfaces import IMTime
 from persistent.interfaces import IPersistent
 from zope.security.proxy import removeSecurityProxy
 import uuid
+from zope.app.zapi import getUtility
+from zope.app.catalog.interfaces import ICatalog
+from ng.adapter.adaptiveurl.adaptiveurl import adaptiveURL
+from ng.content.annotation.profileannotation.interfaces import IProfileAnnotation
 
 class Article2RSSEntryAdapter(object) :
     """ Adapter article to rss-entry """
     def __init__(self,context,request) :
         ps = IPropertySheet(context)
         self.title = ps['title']
-        self.updated = IMTime(context).strftime("%Y-%m-%dT%H-%M-%SZ")
+        self.updated = IMTime(context).strftime("%Y-%m-%dT%H:%M:%SZ")
         self.summary = ps['summary'] or ps['autosummary']
         self.id = uuid.uuid3(uuid.NAMESPACE_OID,IPersistent(removeSecurityProxy(context))._p_oid).urn
         self.link = absoluteURL(context,request)
-
+        for profile in getUtility(ICatalog,context=context) \
+                            .searchResults(
+                                profile=( unicode(context.author), unicode(context.author) )
+                            ) :
+            self.author = IProfileAnnotation(profile).nickname
+        else :
+            self.author = context.author or ""
 
     title = ""
     updated = ""
     summary = ""
     id = ""
     link = ""
-    
+    author = ""    
